@@ -426,7 +426,7 @@ class Extractor:
 """
 if __name__ == '__main__':
     et = Extractor()
-    res = et.extract_reference_no("JR/T0247—2022/证监会公告〔2022〕30号")
+    res = et.extract_reference_no("中国银行业监督管理委员会上海监管局行政处罚决定书（201401）")
     print(res)
     print(datetime.today())
     start = time.time()
